PlanExprOp

Enum PlanExprOp 

pub enum PlanExprOp {
Show 31 variants LoadRegister(u16), PushConstant(i64), Dereference { size: MemoryAccessSize, }, FormTlsAddress, Add, Sub, Mul, Div, Mod, And, Or, Xor, Shl, Shr, Shra, Not, Neg, Abs, Dup, Drop, Swap, Rot, Pick(u8), Eq, Ne, Lt, Le, Gt, Ge, If { then_branch: Vec<PlanExprOp>, else_branch: Vec<PlanExprOp>, }, EntryValueLookup { caller_pc_steps: Vec<PlanExprOp>, cases: Vec<EntryValueCase>, },
}
Stack-machine expression op selected by DWARF lowering.

This is the single planned expression IR shared by DWARF expression lowering, read plans, CFI recovery, and compiler/eBPF lowering.

Variants



LoadRegister(u16)

Load register value from pt_regs



PushConstant(i64)

Push constant



Dereference

Memory dereference via bpf_probe_read_user

Fields



FormTlsAddress

Convert a target-module TLS offset into the current thread’s address.

This models DW_OP_form_tls_address. Runtime lowering is responsible for combining the offset with the thread pointer for the traced thread.



Add

Binary arithmetic operations (pop 2, push 1)



Sub



Mul



Div



Mod



And

Binary bitwise operations



Or



Xor



Shl



Shr



Shra



Not

Unary operations



Neg



Abs



Dup

Stack manipulation



Drop



Swap



Rot



Pick(u8)



Eq

Comparison operations (pop 2, push bool)



Ne



Lt



Le



Gt



Ge



If

Control flow (simplified for eBPF)

Fields

then_branch: Vec<PlanExprOp>
else_branch: Vec<PlanExprOp>


EntryValueLookup

Recover a DW_OP_entry_value at runtime by matching the recovered caller return PC against caller-side DW_AT_call_return_pc cases.

Fields

caller_pc_steps: Vec<PlanExprOp>